@@ -1,5 +1,5 @@
 library(RcppCWB)
-
+use_tmp_registry()
 testthat::context("cl_cpos2lbound")
 
 test_that(
@@ -9,12 +9,28 @@ test_that(
       corpus = "REUTERS",
       s_attribute = "places",
       cpos = 5L,
-      registry = use_tmp_registry()
+      registry = get_tmp_registry()
     )
     expect_equal(cpos, 0)
   }
 )
 
+test_that(
+  "cpos_to_lbound",
+  {
+    cpos_old <- cl_cpos2lbound(
+      corpus = "REUTERS",
+      s_attribute = "places",
+      cpos = 5L,
+      registry = get_tmp_registry()
+    )
+    s <- s_attr(corpus = "REUTERS", s_attribute = "places", registry = get_tmp_registry())
+    cpos_new <- cpos_to_lbound(cpos = 5L, s_attr = s)
+    expect_identical(cpos_old, cpos_new)
+  }
+)
+
+
 test_that(
   "cpos2rbound",
   {
@@ -28,6 +44,22 @@ test_that(
   }
 )
 
+test_that(
+  "cpos_to_rbound",
+  {
+    cpos_old <- cl_cpos2rbound(
+      corpus = "REUTERS",
+      s_attribute = "places",
+      cpos = 5L,
+      registry = get_tmp_registry()
+    )
+    s <- s_attr(corpus = "REUTERS", s_attribute = "places", registry = get_tmp_registry())
+    cpos_new <- cpos_to_rbound(cpos = 5L, s_attr = s)
+    expect_identical(cpos_old, cpos_new)
+  }
+)
+
+
 test_that(
   "",
   {
